Package: copBasic
Title: General Bivariate Copula Theory and Many Utility Functions
Version: 2.2.14
Date: 2026-05-21
Authors@R: person(given = "William",
                  family = "Asquith",
                  role = c("aut", "cre"),
                  email = "william.asquith@ttu.edu",
		  comment = c(ORCID = "0000-0002-7400-1861"))
Description: Extensive functions for bivariate copula (bicopula) computations and related operations
 for bicopula theory. The lower, upper, product, and select other bicopula are implemented along
 with operations including the diagonal, survival copula, dual of a copula, co-copula, and
 numerical bicopula density. Level sets, horizontal and vertical sections are supported. Numerical
 derivatives and inverses of a bicopula are provided through which simulation is implemented.
 Bicopula composition, convex combination, asymmetry extension, and products also are provided.
 Support extends to the Kendall Function as well as the Lmoments thereof. Kendall Tau,
 Spearman Rho and Footrule, Gini Gamma, Blomqvist Beta, Hoeffding Phi, Schweizer-
 Wolff Sigma, tail dependency, tail order, skewness, and bivariate Lmoments are implemented, and
 positive/negative quadrant dependency, left (right) increasing (decreasing) are available.
 Other features include Kullback-Leibler Divergence, Vuong Procedure, spectral measure, and
 Lcomoments for fit and inference, Lcomoment ratio diagrams, maximum likelihood,
 and AIC, BIC, and RMSE for goodness-of-fit.
Maintainer: William Asquith <william.asquith@ttu.edu>
Repository: CRAN
Depends: R (>= 4.0.0)
Imports: lmomco, mvtnorm, randtoolbox
Suggests: copula
License: GPL-2
NeedsCompilation: no
Packaged: 2026-05-22 00:48:07 UTC; wasquith
Author: William Asquith [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7400-1861>)
Date/Publication: 2026-05-22 06:20:03 UTC
Built: R 4.5.2; ; 2026-05-22 11:19:31 UTC; unix
