 importFrom("grDevices", "dev.list", "rgb", "grey")
 importFrom("graphics", "abline", "axTicks", "axis", "contour", "legend", "lines",
                       "mtext", "par", "plot", "points", "rug")
 importFrom("stats", "approx", "complete.cases", "cor", "dnorm",
            "integrate", "median", "qnorm", "quantile", "runif", "var",
            "uniroot", "optimise", "optim", "pnorm", "pt", "qt", "sd",
            "dbeta", "pbeta", "pgamma", "qgamma")
 importFrom("mvtnorm", "GenzBretz", "Miwa", "TVPACK", "pmvnorm", "pmvt")
 importFrom("randtoolbox", "halton", "sobol", "torus")
 importFrom("utils", "installed.packages", "str")
 importFrom("lmomco", "disfitqua", "lmr2par", "lmrloc", "lmoms", "lmom2par", "par2qua", "pp",
                      "rlmomco", "qlmomco", "vec2par")
# --------------------------------------------------------------------------------------------------
export(copBasic.fitpara.beta)
export(AMHcop)
export(CIRCcop)
export(CLcop)
export(COP)
export(COPinv)
export(COPinv2)
export(EMPIRcop)
export(EMPIRcopdf)
export(EMPIRgrid)
export(EMPIRgrid_fast)
export(EMPIRgrid_lkup)
export(EMPIRgridder)
export(EMPIRgridder2)
export(EMPIRgridderinv)
export(EMPIRgridderinv2)
export(EMPIRmed.regress)
export(EMPIRmed.regress2)
export(EMPIRqua.regress)
export(EMPIRqua.regress2)
export(EMPIRsim)
export(EMPIRsimv)
export(EuvCOP)
export(EvuCOP)
export(FGMcop)
export(FGMicop)
export(FRcop)
export(FRECHETcop)
export(GHcop)
export(GLcop)
export(GLEVcop)
export(GLPMcop)
export(HRcop)
export(LpCOP)
export(LpCOPradsym)
export(LpCOPpermsym)
export(LzCOPpermsym)
export(M)
export(M_N5p12b)
export(MOcop)
export(N4212cop)
export(N4220cop)
export(rN4220cop)
export(ORDSUMcop)
export(ORDSUWcop)
export(P)
export(PARETOcop)
export(PAcop)
export(PLACKETTcop)
export(PLcop)
export(PLACKETTpar)
export(PLpar)
export(PLACKETTsim)
export(PSP)
export(RAYcop)
export(RFcop)
export(W)
export(W_N5p12a)
export(aicCOP)
export(asCOP)
export(bilmoms)
export(bicCOP)
export(bicoploc)
export(blomCOP)
export(blomCOPss)
export(blomatrixCOPdec)
export(blomatrixCOPiqr)
export(breveCOP)
export(coCOP)
export(composite1COP)
export(khoudraji1COP)
export(khoudrajiPCOP)
export(composite2COP)
export(khoudraji2COP)
export(composite3COP)
export(concordCOP)
export(convexCOP)
export(convex2COP)
export(densityCOP)
export(densityCOPplot)
export(derCOP)
export(derCOP2)
export(derCOPinv)
export(derCOPinv2)
export(diagCOP)
export(diagCOPatf)
export(diagCOPinv)
export(duCOP)
export(footCOP)
export(gEVcop)
export(giniCOP)
export(glueCOP)
export(gridCOP)
export(HAIRPINcop)
export(hoefCOP)
export(JOcopB5)
export(JOcopBB4)
export(JOMAcop)
export(joeskewCOP)
export(jointCOP)
export(joint.curvesCOP)
export(joint.curvesCOP2)
export(isfuncCOP)
export(isCOP.permsym)
export(isCOP.radsym)
export(isCOP.LTD)
export(isCOP.RTI)
export(isCOP.PQD)
export(kmeasCOP)
export(kfuncCOP)
export(kfuncCOPinv)
export(kfuncCOPlmom)
export(kfuncCOPlmoms)
export(kullCOP)
export(kullCOPint)
export(kfuncCOP_Pd)
export(lcomoms2.ABcop2parameter)
export(lcomoms2.ABKGcop2parameter)
export(lcomCOP)
export(lcomCOPpv)
export(level.curvesCOP)
export(level.curvesCOP2)
export(level.setCOP)
export(level.setCOP2)
export(med.regressCOP)
export(med.regressCOP2)
export(mleCOP)
export(NORMcop)
export(nuskewCOP)
export(nustarCOP)
export(psepolar)
export(prod2COP)
export(qua.regressCOP)
export(qua.regressCOP.draw)
export(qua.regressCOP2)
export(rCOP)
export(rhoCOP)
export(rhobevCOP)
export(rmseCOP)
export(sectionCOP)
export(semicorCOP)
export(simCOP)
export(simCOPmicro)
export(simCOPv)
export(simcomposite3COP)
export(simcompositeCOP)
export(spectralmeas)
export(statTn)
export(surCOP)
export(surfuncCOP)
export(stabtaildepf)
export(tailconCOP)
export(taildepCOP)
export(tailordCOP)
export(tauCOP)
export(tEVcop)
export(Tcop)
export(uvskew)
export(uvlmoms)
export(vuongCOP)
export(wolfCOP)
export(wolfCOPsamc)
export(wolfCOPtest)


